@@ -9,7 +9,7 @@ from .dict_pomes import (
     dict_replace_value, dict_pop_value, dict_unique_values, dict_jsonify, dict_hexify
 )
 from .email_pomes import (
-    EmailParam, email_send
+    EmailConfig, email_send
 )
 from .encoding_pomes import (
     encode_ascii_hex, decode_ascii_hex
@@ -39,9 +39,9 @@ from .obj_pomes import (
 from .str_pomes import (
     str_to_hex, str_from_hex, str_to_lower, str_to_upper,
     str_as_list, str_sanitize, str_split_on_mark,
-    str_between, str_positional, str_random, str_find_char,
-    str_find_whitespace, str_rreplace, str_from_any,
-    str_to_bool, str_to_int, str_to_float
+    str_between, str_positional, str_random, str_splice,
+    str_find_char, str_find_whitespace, str_rreplace,
+    str_from_any, str_to_bool, str_to_int, str_to_float
 )
 from .validation_msgs import (
     validate_set_msgs, validate_update_msgs
@@ -49,7 +49,7 @@ from .validation_msgs import (
 from .validation_pomes import (
     VALIDATION_MSG_LANGUAGE, VALIDATION_MSG_PREFIX,
     validate_value, validate_bool, validate_int, validate_float,
-    validate_str, validate_date, validate_datetime,
+    validate_str, validate_date, validate_datetime, validate_enum,
     validate_ints, validate_strs, validate_build_response,
     validate_format_error, validate_format_errors, validate_unformat_errors
 )
@@ -70,7 +70,7 @@ __all__ = [
     "dict_get_key", "dict_get_keys", "dict_from_object", "dict_from_list",
     "dict_replace_value", "dict_pop_value", "dict_unique_values", "dict_jsonify", "dict_hexify",
     # email_pomes
-    "EmailParam", "email_send",
+    "EmailConfig", "email_send",
     # encoding_pomes
     "encode_ascii_hex", "decode_ascii_hex",
     # env_pomes
@@ -93,15 +93,15 @@ __all__ = [
     # str_pomes
     "str_to_hex", "str_from_hex", "str_to_lower", "str_to_upper",
     "str_as_list", "str_sanitize", "str_split_on_mark",
-    "str_between", "str_positional", "str_random", "str_find_char",
-    "str_find_whitespace", "str_rreplace", "str_from_any",
-    "str_to_bool", "str_to_int", "str_to_float",
+    "str_between", "str_positional", "str_random", "str_splice",
+    "str_find_char", "str_find_whitespace", "str_rreplace",
+    "str_from_any", "str_to_bool", "str_to_int", "str_to_float",
     # validation_msgs
     "validate_set_msgs", "validate_update_msgs",
     # validation_pomes
     "VALIDATION_MSG_LANGUAGE", "VALIDATION_MSG_PREFIX",
     "validate_value", "validate_bool", "validate_int", "validate_float",
-    "validate_str", "validate_date", "validate_datetime",
+    "validate_str", "validate_date", "validate_datetime", "validate_enum",
     "validate_ints", "validate_strs", "validate_build_response",
     "validate_format_error", "validate_format_errors", "validate_unformat_errors",
     # xml_pomes
